<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="defaultlook.ui" line="20"/>
        <location filename="defaultlook.cpp" line="52"/>
        <location filename="defaultlook.cpp" line="464"/>
        <location filename="defaultlook.cpp" line="471"/>
        <location filename="defaultlook.cpp" line="488"/>
        <location filename="defaultlook.cpp" line="499"/>
        <location filename="defaultlook.cpp" line="509"/>
        <source>MX Tweak</source>
        <translation>MX Rifiniture</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Impostazioni di Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizza il pannello&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="77"/>
        <location filename="defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Pannello</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configura il comportamento delle finestre e delle scorciatoie&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Gestore Finestre</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizza il look del tuo desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Backup della configurazione attuale del pannello</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Ripristina la configurazione del pannello dal backup</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Ripristina il pannello di default </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Agisce sul 1° pannello</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Posiziona il pannello verticalmente</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="359"/>
        <source>Bottom</source>
        <translation>in basso</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="364"/>
        <source>Top</source>
        <translation>in alto</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="372"/>
        <source>Display panel horizontally</source>
        <translation>Posiziona il pannello orizzontalmente</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="386"/>
        <source>Left</source>
        <translation>a sinistra</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="391"/>
        <source>Right</source>
        <translation>a destra</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="399"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Effetti su tutti i pannelli&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="419"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pulsanti delle finestre&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="434"/>
        <location filename="defaultlook.ui" line="537"/>
        <location filename="defaultlook.ui" line="707"/>
        <location filename="defaultlook.ui" line="826"/>
        <location filename="defaultlook.ui" line="868"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="457"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="471"/>
        <source>Theme Options</source>
        <translation>Opzioni Tema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="501"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Sistema certe parti dei siti web nell&apos;usare il Tema scuro </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="504"/>
        <source>Firefox dark theme tweak</source>
        <translation>Ritocca il Tema scuro di Firefox</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="511"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Adatta la finestra di gestione di HexChat al tema scuro</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="563"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="570"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="580"/>
        <location filename="defaultlook.ui" line="673"/>
        <source>Compositor</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="601"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Impostazioni del Compositore di Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="604"/>
        <source>Xfwm Settings</source>
        <translation>Impostazioni di Xfwm</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="628"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="633"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositore Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="638"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="646"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Modifica compton.conf direttamente in un editor di testo </translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="649"/>
        <source>Edit compton.conf</source>
        <translation>Modifica compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="680"/>
        <source>Transparency and shadow options</source>
        <translation>Opzioni di trasparenza e ombreggiatura</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="687"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Avvia lo strumento di configurazione compton-conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="690"/>
        <source>Compton settings</source>
        <translation>Impostazioni di Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="743"/>
        <source>Config Options</source>
        <translation>Config. Opzioni</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="751"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reimposta Lightdm (shermata di login) al tema di default del sistema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="758"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Reimposta le azioni personalizzate del pulsante destro in Thunar ai valori di default del sistema</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="765"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Usa il driver intel invece del driver &quot;modsetting&quot; predefinito (sarà necessario riavviare)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="772"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTA: Verrà fatto un back up nella directory home dell&apos;attuale file /etc/X11/xorg.conf.d/20-intel.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="779"/>
        <source>Use tearfree amdgpu option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="786"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="793"/>
        <source>Use tearfree radeon driver option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="800"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="840"/>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="848"/>
        <source>Enable single-click on desktop</source>
        <translation>Abilita il click-singolo sul desktop</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="855"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Abilita il click-singolo sul Gestore di File Thunar</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="892"/>
        <source>Show systray (notification area) frame</source>
        <translation>Mostra la systray (area di notifica)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="899"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro nel pannello</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="906"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Permetti il montaggio delle periferiche interne agli utenti non-root</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="913"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Disabilitare l&apos;accorciamento dei nomi lunghi dei file nel desktop</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="920"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Abilita l&apos;ibernazione sul menu di chiusura</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="927"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   nota: per l&apos;ibernazione, la swap deve essere &gt;= RAM</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="463"/>
        <source>About MX Tweak</source>
        <translation>Informazioni su MX Rifiniture</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="464"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="465"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Applicazione per ritocchi e rapide modifiche ai temi predefiniti dell&apos;interfaccia </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="467"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="468"/>
        <location filename="defaultlook.cpp" line="471"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="469"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="500"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Finito! Potrebbe essere necessario riavviare Firefox perchè le modifiche abbiano effetto</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="510"/>
        <source>This app is Xfce-only</source>
        <translation>Questa applicazione è solo per Xfce </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="652"/>
        <source>Panel settings</source>
        <translation>Impostazioni Pannello </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="653"/>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Le tue attuali impostazioni del pannello sono state ricopiate in una cartella nascosta chiamata .restore presente nella tua cartella utente (~/.restore/) </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="1070"/>
        <source>Choose a theme set</source>
        <translation>Scegli un set di temi</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="window_buttons.ui" line="14"/>
        <location filename="window_buttons.cpp" line="36"/>
        <source>Window Buttons</source>
        <translation>Pulsanti delle finestre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aspetto&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Mostra le etichette dei pulsanti</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Usa pulsanti piatti</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Mostra maniglie</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordinamento:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Timestamp</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titolo del gruppo e timestamp</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Titolo della finestra</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titolo del gruppo e della finestra</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Nessuno, permetti drag&amp;drop</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportamento&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Raggruppa finestre:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Azione del tasto centrale:</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Non fare niente</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Chiude la finestra</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimizza la finestra</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Ripristina le finestre minimizzate nello spazio di lavoro corrente</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Disegna la cornice della finestra quando il puntatore è sul suo pulsante</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Scorri tra le finestre usando la rotella del mouse</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtraggio&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostra le finestre di tutti gli spazi di lavoro o porzioni</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Mostra solo le finestre minimizzate</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Mostra le finestre di tutti gli schermi</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Finestre a comparsa</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Finestre durante lo spostamento</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Impostazioni Opacità&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Decorazioni della finestra</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre della barra dock</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre a comparsa</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Finestre durante il ridimensionamento</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostra l&apos;ombra sotto le finestre normali</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Impostazione delle funzioni&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostra l&apos;anteprima delle finestre al posto delle icone al passaggio</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Visualizza direttamente a pieno schermo le finestre sovrapposte</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Finestre inattive</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizza il disegno allo spazio vuoto verticale</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.cpp" line="38"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Impostazioni del Compositore Xfwm </translation>
    </message>
</context>
</TS>